@@ -2,33 +2,38 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-use crate::manifest::SyntaxOption;
 use displaydoc::Display;
+use icu_provider::DataError;
 use std::path::{Path, PathBuf};
 
 #[derive(Display, Debug)]
+#[non_exhaustive]
 pub enum Error {
     #[displaydoc("{0}: {1:?}")]
     Io(std::io::Error, Option<PathBuf>),
     #[displaydoc("{0}")]
-    DataProvider(icu_provider::DataError),
+    DataProvider(DataError),
     #[displaydoc("Deserializer error: {0}: {1:?}")]
     Deserializer(String, Option<PathBuf>),
     #[cfg(feature = "export")]
     #[displaydoc("Serializer error: {0}: {1:?}")]
     Serializer(erased_serde::Error, Option<PathBuf>),
-    #[displaydoc("Unknown syntax {0:?}. Do you need to enable a feature?")]
-    UnknownSyntax(SyntaxOption),
 }
 
 impl std::error::Error for Error {}
 
-impl From<icu_provider::DataError> for Error {
-    fn from(e: icu_provider::DataError) -> Self {
+impl From<DataError> for Error {
+    fn from(e: DataError) -> Self {
         Error::DataProvider(e)
     }
 }
 
+impl From<icu_provider::serde::Error> for Error {
+    fn from(e: icu_provider::serde::Error) -> Self {
+        Error::DataProvider(e.into())
+    }
+}
+
 /// To help with debugging, I/O errors should be paired with a file path.
 /// If a path is unavailable, create the error directly: [`Error::Io`]`(err, `[`None`]`)`
 impl<P: AsRef<Path>> From<(std::io::Error, P)> for Error {
@@ -39,8 +44,8 @@ impl<P: AsRef<Path>> From<(std::io::Error, P)> for Error {
 
 /// To help with debugging, JSON errors should be paired with a file path.
 /// If a path is unavailable, create the error directly: [`Error::Deserializer`]`(err, `[`None`]`)`
-impl<P: AsRef<Path>> From<(serde_json::error::Error, P)> for Error {
-    fn from(pieces: (serde_json::error::Error, P)) -> Self {
+impl<P: AsRef<Path>> From<(serde_json_core::de::Error, P)> for Error {
+    fn from(pieces: (serde_json_core::de::Error, P)) -> Self {
         Self::Deserializer(
             format!("{}", pieces.0),
             Some(pieces.1.as_ref().to_path_buf()),
@@ -72,8 +77,23 @@ impl Error {
     }
 }
 
-impl From<Error> for icu_provider::DataError {
+impl From<Error> for DataError {
     fn from(err: Error) -> Self {
-        Self::new_resc_error(&err)
+        use Error::*;
+        match err {
+            Io(e, Some(path_buf)) => DataError::from(e).with_path(&path_buf),
+            Io(e, None) => DataError::from(e),
+            DataProvider(e) => e,
+            Deserializer(s, Some(path_buf)) => DataError::custom("FS: Deserializer")
+                .with_display_context(&s)
+                .with_path(&path_buf),
+            Deserializer(s, None) => DataError::custom("FS: Deserializer").with_display_context(&s),
+            #[cfg(feature = "export")]
+            Serializer(e, Some(path_buf)) => DataError::custom("FS: Serializer")
+                .with_error_context(&e)
+                .with_path(&path_buf),
+            #[cfg(feature = "export")]
+            Serializer(e, None) => DataError::custom("FS: Serializer").with_display_context(&e),
+        }
     }
 }
