@@ -4,34 +4,18 @@
 
 use super::AbstractSerializer;
 use super::Error;
-use crate::manifest::SyntaxOption;
 use bincode::config::Options as _;
+use icu_provider::buf::BufferFormat;
 use std::io;
-use std::ops::Deref;
 
 /// A serializer for Bincode.
-pub struct Serializer {
-    syntax: SyntaxOption,
-}
+#[allow(clippy::exhaustive_structs)] // this type is stable
+pub struct Serializer;
 
 /// Options bag for initializing a [`bincode::Serializer`].
 #[non_exhaustive]
-#[derive(Clone, Debug, PartialEq)]
-pub struct Options {}
-
-impl Default for Options {
-    fn default() -> Self {
-        Self {}
-    }
-}
-
-impl Deref for Serializer {
-    type Target = SyntaxOption;
-
-    fn deref(&self) -> &Self::Target {
-        &self.syntax
-    }
-}
+#[derive(Clone, Debug, PartialEq, Default)]
+pub struct Options;
 
 impl AbstractSerializer for Serializer {
     fn serialize(
@@ -47,12 +31,20 @@ impl AbstractSerializer for Serializer {
         ))?;
         Ok(())
     }
+
+    fn get_buffer_format(&self) -> BufferFormat {
+        BufferFormat::Bincode1
+    }
 }
 
 impl Serializer {
     pub fn new(_options: Options) -> Self {
-        Self {
-            syntax: SyntaxOption::Bincode,
-        }
+        Self {}
+    }
+}
+
+impl Default for Serializer {
+    fn default() -> Self {
+        Self::new(Default::default())
     }
 }
