@@ -2,18 +2,17 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-pub mod json;
-
-#[cfg(feature = "bincode")]
 pub mod bincode;
+pub mod json;
+pub mod postcard;
 
-use crate::manifest::SyntaxOption;
 use displaydoc::Display;
+use icu_provider::buf::BufferFormat;
 use std::io;
-use std::ops::Deref;
 
 /// An Error type specifically for the [`Serializer`](serde::Serializer) that doesn't carry filenames
 #[derive(Display, Debug)]
+#[non_exhaustive]
 pub enum Error {
     #[displaydoc("{0}")]
     Io(io::Error),
@@ -34,12 +33,16 @@ impl From<erased_serde::Error> for Error {
         Error::Serializer(e)
     }
 }
+
 /// A simple serializer trait that works on whole objects.
-pub trait AbstractSerializer: Deref<Target = SyntaxOption> {
+pub trait AbstractSerializer {
     /// Serializes an object to a sink.
     fn serialize(
         &self,
         obj: &dyn erased_serde::Serialize,
         sink: &mut dyn io::Write,
     ) -> Result<(), Error>;
+
+    /// Gets the buffer format currently being serialized.
+    fn get_buffer_format(&self) -> BufferFormat;
 }
